@@ -34,10 +34,10 @@
 #include "globalconfig.h"
 #include "debug.h"
 
-TrafficMonitor::TrafficMonitor(QGraphicsItem* parent):
-    QGraphicsWidget(parent, 0),
-    m_device(0),
-    m_updateEnabled(false)
+TrafficMonitor::TrafficMonitor(QGraphicsItem* parent)
+    : QGraphicsWidget(parent, 0)
+    , m_device(0)
+    , m_updateEnabled(false)
 {
     QGraphicsLinearLayout * layout = new QGraphicsLinearLayout(this);
     layout->setOrientation(Qt::Vertical);
@@ -72,6 +72,8 @@ TrafficMonitor::TrafficMonitor(QGraphicsItem* parent):
     setLayout(layout);
 
     Plasma::DataEngineManager::self()->loadEngine("systemmonitor");
+
+    connect(m_traffic, SIGNAL(heightChanged()), this, SIGNAL(heightChanged()));
 }
 
 TrafficMonitor::~TrafficMonitor()
@@ -122,6 +124,11 @@ QString TrafficMonitor::device() const
     return QString();
 }
 
+qreal TrafficMonitor::height() const
+{
+    return m_trafficPlotter->geometry().height() + m_traffic->geometry().height() + 5;
+}
+
 void TrafficMonitor::resetMonitor()
 {
     const QString format = "<b>%1:</b>&nbsp;%2";
