@@ -27,9 +27,9 @@
 
 #include "debug.h"
 
-Model::Model(QObject* parent):
-    QAbstractListModel(parent),
-    m_monitor(new Monitor(this))
+Model::Model(QObject* parent)
+    : QAbstractListModel(parent)
+    , m_monitor(new Monitor(this))
 {
     QHash<int, QByteArray> roles = roleNames();
     roles[ConnectionStateRole] = "itemConnectionState";
@@ -68,8 +68,8 @@ Model::Model(QObject* parent):
             SLOT(modemPropertiesChanged(QString)));
     connect(m_monitor, SIGNAL(modemAllowedModeChanged(QString)),
             SLOT(modemPropertiesChanged(QString)));
-    connect(m_monitor, SIGNAL(modemSignalQualityChanged(uint, QString)),
-            SLOT(modemSignalQualityChanged(uint, QString)));
+    connect(m_monitor, SIGNAL(modemSignalQualityChanged(uint,QString)),
+            SLOT(modemSignalQualityChanged(uint,QString)));
 #endif
     connect(m_monitor, SIGNAL(removeActiveConnection(QString)),
             SLOT(removeActiveConnection(QString)));
@@ -230,7 +230,7 @@ void Model::addConnection(const QString& connection, const QString& device)
 {
     NetworkManager::Connection::Ptr con = NetworkManager::findConnection(connection);
 
-    if (con->settings()->isSlave()) {
+    if (con->settings()->isSlave() || con->name().isEmpty() || con->uuid().isEmpty()) {
         return;
     }
 
@@ -395,7 +395,11 @@ void Model::removeWirelessNetwork(const QString& ssid, const QString& device)
         if (wirelessDevice) {
             accessPoint = wirelessDevice->findAccessPoint(item->specificPath());
         }
-        if (accessPoint && accessPoint->mode() == NetworkManager::AccessPoint::Adhoc &&
+
+        // When accesspoint in ad-hoc mode dissapears, we should remove the item only when there is no connection. Similar case is when
+        // a wireless device is in AP mode, but in this case there could be only one visible AP and this should always be associated with some connection.
+        if (accessPoint && ((accessPoint->mode() == NetworkManager::AccessPoint::Adhoc && !item->connectionPath().isEmpty()) ||
+                            wirelessDevice->mode() == NetworkManager::WirelessDevice::ApMode) &&
             NetworkManager::isWirelessEnabled() && NetworkManager::isWirelessHardwareEnabled()) {
             item->setWirelessNetwork(QString());
             if (updateItem(item)) {
@@ -455,22 +459,11 @@ void Model::insertItem(ModelItem * item)
 {
     bool found = false;
     bool updated = false;
+
     foreach (ModelItem * it, m_items.items()) {
-        // Check for duplicity
+        // Check whether the items are equal, it means they have same UUID or SSID
         if (it->operator==(item)) {
             found = true;
-
-            // Update info
-            if (it->specificPath().isEmpty() && !item->specificPath().isEmpty()) {
-                NMModelDebug() << "Connection " << it->name() << " has been updated by wireless network";
-                if (item->type() == NetworkManager::ConnectionSettings::Wireless) {
-                    it->setWirelessNetwork(item->ssid());
-                } else if (item->type() == NetworkManager::ConnectionSettings::Wimax) {
-                    it->setNsp(item->nspPath());
-                }
-                updated = true;
-            }
-
             if (it->connectionPath().isEmpty() && !item->connectionPath().isEmpty()) {
                 NMModelDebug() << "Connection " << it->name() << " has been updated by connection";
                 it->setConnection(item->connectionPath());
@@ -485,8 +478,6 @@ void Model::insertItem(ModelItem * item)
                     emit dataChanged(index, index);
                 }
             }
-
-            break;
         }
     }
     // Item doesn't exist, let's add it
