@@ -31,8 +31,8 @@
 
 #include "debug.h"
 
-Monitor::Monitor(QObject* parent):
-    QObject(parent)
+Monitor::Monitor(QObject* parent)
+    : QObject(parent)
 {
 }
 
@@ -78,7 +78,7 @@ void Monitor::init()
             NetworkManager::VpnConnection::Ptr vpnConnection = active.objectCast<NetworkManager::VpnConnection>();
             if (vpnConnection) {
                 connect(vpnConnection.data(), SIGNAL(stateChanged(NetworkManager::VpnConnection::State,NetworkManager::VpnConnection::StateChangeReason)),
-                        SLOT(vpnConnectionStateChanged(NetworkManager::VpnConnection::State, NetworkManager::VpnConnection::StateChangeReason)));
+                        SLOT(vpnConnectionStateChanged(NetworkManager::VpnConnection::State,NetworkManager::VpnConnection::StateChangeReason)));
             }
         } else {
             connect(active.data(), SIGNAL(stateChanged(NetworkManager::ActiveConnection::State)),
@@ -108,7 +108,7 @@ void Monitor::addDevice(const NetworkManager::Device::Ptr& device)
         connect(wiredDev.data(), SIGNAL(carrierChanged(bool)),
                 SLOT(cablePlugged(bool)), Qt::UniqueConnection);
 
-    }  else if (device->type() == NetworkManager::Device::Wimax) {
+    } else if (device->type() == NetworkManager::Device::Wimax) {
         NMMonitorDebug() << "Available wimax device " << device->interfaceName();
         NetworkManager::WimaxDevice::Ptr wimaxDev = device.objectCast<NetworkManager::WimaxDevice>();
 
@@ -230,7 +230,7 @@ void Monitor::activeConnectionAdded(const QString& active)
             NetworkManager::VpnConnection::Ptr vpnConnection = activeConnection.objectCast<NetworkManager::VpnConnection>();
             if (vpnConnection) {
                 connect(vpnConnection.data(), SIGNAL(stateChanged(NetworkManager::VpnConnection::State,NetworkManager::VpnConnection::StateChangeReason)),
-                        SLOT(vpnConnectionStateChanged(NetworkManager::VpnConnection::State, NetworkManager::VpnConnection::StateChangeReason)));
+                        SLOT(vpnConnectionStateChanged(NetworkManager::VpnConnection::State,NetworkManager::VpnConnection::StateChangeReason)));
             }
         } else {
             connect(activeConnection.data(), SIGNAL(stateChanged(NetworkManager::ActiveConnection::State)),
