@@ -61,6 +61,8 @@ ConnectionEditor::ConnectionEditor(QWidget* parent, Qt::WindowFlags flags):
     m_editor->setupUi(tmp);
     setCentralWidget(tmp);
 
+    m_editor->connectionsWidget->header()->setResizeMode(0, QHeaderView::Stretch);
+
     m_editor->ktreewidgetsearchline->setTreeWidget(m_editor->connectionsWidget);
 
     m_menu = new KActionMenu(KIcon("list-add"), i18n("Add"), this);
@@ -224,6 +226,19 @@ void ConnectionEditor::insertConnection(const NetworkManager::Connection::Ptr &c
         return;
     }
 
+    if (type == "vpn") { // check if the corresponding VPN plugin is installed
+        NetworkManager::VpnSetting::Ptr vpnSetting = connection->settings()->setting(NetworkManager::Setting::Vpn).dynamicCast<NetworkManager::VpnSetting>();
+        qDebug() << "CHECKING VPN" << connection->name() << "type:" << vpnSetting->serviceType();
+
+        // get the list of supported VPN service types
+        const KService::List services = KServiceTypeTrader::self()->query("PlasmaNetworkManagement/VpnUiPlugin",
+                                                                          QString::fromLatin1("[X-NetworkManager-Services]=='%1'").arg(vpnSetting->serviceType()));
+        if (services.isEmpty()) {
+            qDebug() << "VPN" << vpnSetting->serviceType() << "not found, skipping";
+            return;
+        }
+    }
+
     QStringList actives;
 
     foreach(const NetworkManager::ActiveConnection::Ptr & active, NetworkManager::activeConnections()) {
@@ -340,7 +355,7 @@ void ConnectionEditor::addConnection(QAction* action)
         QWeakPointer<MobileConnectionWizard> wizard = new MobileConnectionWizard(NetworkManager::ConnectionSettings::Unknown, this);
         if (wizard.data()->exec() == QDialog::Accepted && wizard.data()->getError() == MobileProviders::Success) {
             qDebug() << "Mobile broadband wizard finished:" << wizard.data()->type() << wizard.data()->args();
-            ConnectionDetailEditor * editor = new ConnectionDetailEditor(wizard.data()->type(), wizard.data()->args(), this);
+            QPointer<ConnectionDetailEditor> editor = new ConnectionDetailEditor(wizard.data()->type(), wizard.data()->args(), this);
             editor->exec();
         }
         if (wizard) {
