@@ -28,8 +28,13 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <KPushButton>
 #include <Solid/Device>
 
-#include <ModemManagerQt/modeminterface.h>
+#include "config.h"
 
+#ifdef MODEMMANAGERQT_ONE
+#include <ModemManagerQt/modem.h>
+#else
+#include <ModemManagerQt/modeminterface.h>
+#endif
 #include "ui_pinwidget.h"
 
 class PinWidget;
@@ -38,10 +43,33 @@ class PinDialog : public KDialog
 {
     Q_OBJECT
 public:
+#ifdef MODEMMANAGERQT_ONE
+    enum Type {
+        SimPin,
+        SimPin2,
+        SimPuk,
+        SimPuk2,
+        ModemServiceProviderPin,
+        ModemServiceProviderPuk,
+        ModemNetworkPin,
+        ModemNetworkPuk,
+        ModemPin,
+        ModemCorporatePin,
+        ModemCorporatePuk,
+        ModemPhFsimPin,
+        ModemPhFsimPuk,
+        ModemNetworkSubsetPin,
+        ModemNetworkSubsetPuk
+    };
+#else
     enum Type {Pin, PinPuk};
+#endif
     enum ErrorCode {PinCodeTooShort, PinCodesDoNotMatch, PukCodeTooShort};
-
+#ifdef MODEMMANAGERQT_ONE
+    explicit PinDialog(ModemManager::Modem *modem, const Type type = SimPin, QWidget *parent=0);
+#else
     explicit PinDialog(ModemManager::ModemInterface *modem, const Type type = Pin, QWidget *parent=0);
+#endif
     ~PinDialog();
 
     Type type() const;
@@ -58,6 +86,8 @@ private Q_SLOTS:
 
 private:
     void showErrorMessage(const PinDialog::ErrorCode);
+    bool isPukDialog() const;
+    bool isPinDialog() const;
     Ui::PinWidget * ui;
     QLabel* pixmapLabel;
     QString m_name;
