@@ -570,24 +570,6 @@ QString UiUtils::wirelessBandToString(NetworkManager::WirelessSetting::Frequency
 
 #if WITH_MODEMMANAGER_SUPPORT
 #ifdef MODEMMANAGERQT_ONE
-// QString UiUtils::convertTypeToString(ModemManager::Modem::InterfaceType type)
-// {
-//     switch (type) {
-//         case ModemManager::ModemInterface::Gsm: return i18nc("Gsm cellular type","Gsm");
-//         case ModemManager::ModemInterface::Cdma: return i18nc("Cdma cellular type","Cdma");
-//     }
-//
-//     return i18nc("Unknown cellular type","Unknown");
-// }
-
-QString UiUtils::convertBandsToString(const QList<MMModemBand> &band)
-{
-    // TODO
-    Q_UNUSED(band);
-
-    return i18nc("Unknown cellular frequency band","Unknown");
-}
-
 QString UiUtils::convertAllowedModeToString(ModemManager::Modem::ModemModes modes)
 {
     if (modes.testFlag(MM_MODEM_MODE_4G)) {
@@ -686,8 +668,6 @@ QString UiUtils::convertLockReasonToString(MMModemLock reason)
         return i18nc("possible SIM lock reason", "Lock reason unknown.");
     }
 }
-
-
 #else
 QString UiUtils::convertTypeToString(const ModemManager::ModemInterface::Type type)
 {
@@ -855,11 +835,11 @@ QString UiUtils::shortToolTipFromWirelessSecurity(NetworkManager::Utils::Wireles
 
 QString UiUtils::connectionDetails(const Device::Ptr& device, const Connection::Ptr& connection, const QStringList& keys)
 {
-    QString format = "<tr><td align=\"right\" width=\"50%\"><b>%1</b></td><td align=\"left\" width=\"50%\">&nbsp;%2</td></tr>";
+    const QString format = "<tr><td align=\"right\" width=\"50%\"><b>%1</b></td><td align=\"left\" width=\"50%\">&nbsp;%2</td></tr>";
     QString details;
 
-    bool connected = device && connection && device->activeConnection() &&
-                     device->activeConnection()->connection() == connection && device->activeConnection()->state() == ActiveConnection::Activated;
+    const bool connected = device && connection && device->activeConnection() &&
+                           device->activeConnection()->connection() == connection && device->activeConnection()->state() == ActiveConnection::Activated;
 
     foreach (const QString& key, keys) {
         if (key == "interface:type") {
@@ -944,7 +924,7 @@ QString UiUtils::connectionDetails(const Device::Ptr& device, const Connection::
 
 QString UiUtils::bluetoothDetails(const BluetoothDevice::Ptr& btDevice, const QStringList& keys)
 {
-    QString format = "<tr><td align=\"right\" width=\"50%\"><b>%1</b></td><td align=\"left\" width=\"50%\">&nbsp;%2</td></tr>";
+    const QString format = "<tr><td align=\"right\" width=\"50%\"><b>%1</b></td><td align=\"left\" width=\"50%\">&nbsp;%2</td></tr>";
     QString details;
 
     foreach (const QString& key, keys) {
@@ -967,7 +947,7 @@ QString UiUtils::bluetoothDetails(const BluetoothDevice::Ptr& btDevice, const QS
 QString UiUtils::modemDetails(const ModemDevice::Ptr& modemDevice, const QStringList& keys)
 {
 #if WITH_MODEMMANAGER_SUPPORT
-    QString format = "<tr><td align=\"right\" width=\"50%\"><b>%1</b></td><td align=\"left\" width=\"50%\">&nbsp;%2</td></tr>";
+    const QString format = "<tr><td align=\"right\" width=\"50%\"><b>%1</b></td><td align=\"left\" width=\"50%\">&nbsp;%2</td></tr>";
     QString details;
 #ifdef MODEMMANAGERQT_ONE
     ModemManager::Modem::Ptr modemNetwork;
@@ -1000,10 +980,6 @@ QString UiUtils::modemDetails(const ModemDevice::Ptr& modemDevice, const QString
             if (modemNetwork) {
                 details += QString(format).arg(i18n("Allowed Mode:"), UiUtils::convertAllowedModeToString(modemNetwork->currentModes().allowed));
             }
-        } else if (key == "mobile:band") {
-            if (modemNetwork) {
-                details += QString(format).arg(i18n("Frequency Bands:"), UiUtils::convertBandsToString(modemNetwork->currentBands()));
-            }
         } else if (key == "mobile:unlock") {
             if (modemNetwork) {
                 details += QString(format).arg(i18n("Unlock Required:"), UiUtils::convertLockReasonToString(modemNetwork->unlockRequired()));
@@ -1079,7 +1055,7 @@ QString UiUtils::modemDetails(const ModemDevice::Ptr& modemDevice, const QString
 
 QString UiUtils::vpnDetails(const VpnConnection::Ptr& vpnConnection, const VpnSetting::Ptr& vpnSetting, const QStringList& keys)
 {
-    QString format = "<tr><td align=\"right\" width=\"50%\"><b>%1</b></td><td align=\"left\" width=\"50%\">&nbsp;%2</td></tr>";
+    const QString format = "<tr><td align=\"right\" width=\"50%\"><b>%1</b></td><td align=\"left\" width=\"50%\">&nbsp;%2</td></tr>";
     QString details;
 
     foreach (const QString& key, keys) {
@@ -1099,11 +1075,11 @@ QString UiUtils::vpnDetails(const VpnConnection::Ptr& vpnConnection, const VpnSe
 
 QString UiUtils::wimaxDetails(const NetworkManager::WimaxDevice::Ptr& wimaxDevice, const WimaxNsp::Ptr& wimaxNsp, const NetworkManager::Connection::Ptr& connection, const QStringList& keys)
 {
-    QString format = "<tr><td align=\"right\" width=\"50%\"><b>%1</b></td><td align=\"left\" width=\"50%\">&nbsp;%2</td></tr>";
+    const QString format = "<tr><td align=\"right\" width=\"50%\"><b>%1</b></td><td align=\"left\" width=\"50%\">&nbsp;%2</td></tr>";
     QString details;
 
-    bool connected = wimaxDevice && connection && wimaxDevice->activeConnection() &&
-                     wimaxDevice->activeConnection()->connection() == connection && wimaxDevice->activeConnection()->state() == ActiveConnection::Activated;
+    const bool connected = wimaxDevice && connection && wimaxDevice->activeConnection() &&
+                           wimaxDevice->activeConnection()->connection() == connection && wimaxDevice->activeConnection()->state() == ActiveConnection::Activated;
 
     foreach (const QString& key, keys) {
         if (key == "wimax:bsid") {
@@ -1130,11 +1106,11 @@ QString UiUtils::wimaxDetails(const NetworkManager::WimaxDevice::Ptr& wimaxDevic
 
 QString UiUtils::wiredDetails(const WiredDevice::Ptr& wiredDevice, const NetworkManager::Connection::Ptr& connection, const QStringList& keys)
 {
-    QString format = "<tr><td align=\"right\" width=\"50%\"><b>%1</b></td><td align=\"left\" width=\"50%\">&nbsp;%2</td></tr>";
+    const QString format = "<tr><td align=\"right\" width=\"50%\"><b>%1</b></td><td align=\"left\" width=\"50%\">&nbsp;%2</td></tr>";
     QString details;
 
-    bool connected = wiredDevice && connection && wiredDevice->activeConnection() &&
-                     wiredDevice->activeConnection()->connection() == connection && wiredDevice->activeConnection()->state() == ActiveConnection::Activated;
+    const bool connected = wiredDevice && connection && wiredDevice->activeConnection() &&
+                           wiredDevice->activeConnection()->connection() == connection && wiredDevice->activeConnection()->state() == ActiveConnection::Activated;
 
     foreach (const QString& key, keys) {
         if (key == "interface:bitrate") {
@@ -1153,11 +1129,11 @@ QString UiUtils::wiredDetails(const WiredDevice::Ptr& wiredDevice, const Network
 
 QString UiUtils::wirelessDetails(const WirelessDevice::Ptr& wirelessDevice, const WirelessNetwork::Ptr& network, const NetworkManager::Connection::Ptr& connection, const QStringList& keys)
 {
-    QString format = "<tr><td align=\"right\" width=\"50%\"><b>%1</b></td><td align=\"left\" width=\"50%\">&nbsp;%2</td></tr>";
+    const QString format = "<tr><td align=\"right\" width=\"50%\"><b>%1</b></td><td align=\"left\" width=\"50%\">&nbsp;%2</td></tr>";
     QString details;
 
-    bool connected = wirelessDevice && connection && wirelessDevice->activeConnection() &&
-                     wirelessDevice->activeConnection()->connection() == connection && wirelessDevice->activeConnection()->state() == ActiveConnection::Activated;
+    const bool connected = wirelessDevice && connection && wirelessDevice->activeConnection() &&
+                           wirelessDevice->activeConnection()->connection() == connection && wirelessDevice->activeConnection()->state() == ActiveConnection::Activated;
 
     NetworkManager::AccessPoint::Ptr ap;
     if (network) {
@@ -1202,7 +1178,7 @@ QString UiUtils::wirelessDetails(const WirelessDevice::Ptr& wirelessDevice, cons
                     details += QString(format).arg(i18n("Security:"), UiUtils::labelFromWirelessSecurity(security));
                 }
             } else if (connection) {
-                // Neccessary for example for AdHoc connections
+                // Necessary for example for AdHoc connections
                 security = Utils::securityTypeFromConnectionSetting(connection->settings());
                 if (security != Utils::Unknown) {
                     details += QString(format).arg(i18n("Security:"), UiUtils::labelFromWirelessSecurity(security));
@@ -1217,4 +1193,3 @@ QString UiUtils::wirelessDetails(const WirelessDevice::Ptr& wirelessDevice, cons
 
     return details;
 }
-
